def per_of(percent: int,of: int):# % ของ  เท่ากับเท่าไร 
 return (of/100)*percent
def per_is(num1: int,num2: int):# คิดเป็นกี่เปอร์เซ็นต์ของ
 return (num1/num2)*100
def per_from(num: int,percent: int):# เป็น % ของจำนวนใด
 return(num/percent)*100